@@ -1,5 +1,7 @@
 (function() {var implementors = {};
-implementors['alloc'] = [];
+implementors["alloc"] = [];
+implementors["collections"] = [];
+implementors["proc_macro"] = [];
 
             if (window.register_implementors) {
                 window.register_implementors(implementors);
